@@ -1,7 +1,7 @@
 pub use self::config::InterpreterConfig;
 use crate::auditwheel::PlatformTag;
 use crate::{BridgeModel, BuildContext, Target};
-use anyhow::{bail, format_err, Context, Result};
+use anyhow::{bail, ensure, format_err, Context, Result};
 use pep440_rs::{Version, VersionSpecifiers};
 use regex::Regex;
 use serde::Deserialize;
@@ -12,7 +12,7 @@ use std::ops::Deref;
 use std::path::{Path, PathBuf};
 use std::process::{Command, Stdio};
 use std::str::{self, FromStr};
-use tracing::debug;
+use tracing::{debug, instrument};
 
 mod config;
 
@@ -21,7 +21,7 @@ mod config;
 const GET_INTERPRETER_METADATA: &str = include_str!("get_interpreter_metadata.py");
 pub const MINIMUM_PYTHON_MINOR: usize = 7;
 /// Be liberal here to include preview versions
-pub const MAXIMUM_PYTHON_MINOR: usize = 12;
+pub const MAXIMUM_PYTHON_MINOR: usize = 13;
 pub const MAXIMUM_PYPY_MINOR: usize = 10;
 
 /// Identifies conditions where we do not want to build wheels
@@ -245,7 +245,13 @@ fn find_all_windows(
     Ok(interpreter)
 }
 
-fn windows_python_info(executable: &Path) -> Result<Option<InterpreterConfig>> {
+struct WindowsPythonInfo {
+    major: usize,
+    minor: usize,
+    pointer_width: Option<usize>,
+}
+
+fn windows_python_info(executable: &Path) -> Result<Option<WindowsPythonInfo>> {
     let python_info = Command::new(executable)
         .arg("-c")
         .arg("import sys; print(sys.version)")
@@ -276,12 +282,9 @@ fn windows_python_info(executable: &Path) -> Result<Option<InterpreterConfig>> {
         } else {
             32
         };
-        Ok(Some(InterpreterConfig {
+        Ok(Some(WindowsPythonInfo {
             major,
             minor,
-            interpreter_kind: InterpreterKind::CPython,
-            abiflags: String::new(),
-            ext_suffix: String::new(),
             pointer_width: Some(pointer_width),
         }))
     } else {
@@ -353,6 +356,7 @@ struct InterpreterMetadataMessage {
     // comes from `platform.system()`
     system: String,
     soabi: Option<String>,
+    gil_disabled: bool,
 }
 
 /// The location and version of an interpreter
@@ -423,21 +427,33 @@ fn fun_with_abiflags(
         Ok("".to_string())
     } else if message.system == "windows" {
         if matches!(message.abiflags.as_deref(), Some("") | None) {
-            Ok("".to_string())
+            // windows has a few annoying cases, but its abiflags in sysconfig always empty
+            // python <= 3.7 has "m"
+            if message.minor <= 7 {
+                Ok("m".to_string())
+            } else if message.gil_disabled {
+                ensure!(
+                    message.minor >= 13,
+                    "gil_disabled is only available in python 3.13+ ಠ_ಠ"
+                );
+                Ok("t".to_string())
+            } else {
+                Ok("".to_string())
+            }
         } else {
-            bail!("A python 3 interpreter on windows does not define abiflags in its sysconfig ಠ_ಠ")
+            bail!("A python 3 interpreter on Windows does not define abiflags in its sysconfig ಠ_ಠ")
         }
     } else if let Some(ref abiflags) = message.abiflags {
         if message.minor >= 8 {
             // for 3.8, "builds with and without pymalloc are ABI compatible" and the flag dropped
             Ok(abiflags.to_string())
         } else if (abiflags != "m") && (abiflags != "dm") {
-            bail!("A python 3 interpreter on linux or mac os must have 'm' or 'dm' as abiflags ಠ_ಠ")
+            bail!("A python 3 interpreter on Linux or macOS must have 'm' or 'dm' as abiflags ಠ_ಠ")
         } else {
             Ok(abiflags.to_string())
         }
     } else {
-        bail!("A python 3 interpreter on linux or mac os must define abiflags in its sysconfig ಠ_ಠ")
+        bail!("A python 3 interpreter on Linux or macOS must define abiflags in its sysconfig ಠ_ಠ")
     }
 }
 
@@ -448,7 +464,8 @@ impl PythonInterpreter {
             false
         } else {
             match self.interpreter_kind {
-                InterpreterKind::CPython => true,
+                // Free-threaded python does not have stable api support yet
+                InterpreterKind::CPython => !self.config.gil_disabled,
                 InterpreterKind::PyPy | InterpreterKind::GraalPy => false,
             }
         }
@@ -494,23 +511,13 @@ impl PythonInterpreter {
         } else {
             match self.interpreter_kind {
                 InterpreterKind::CPython => {
-                    if target.is_unix() {
-                        format!(
-                            "cp{major}{minor}-cp{major}{minor}{abiflags}-{platform}",
-                            major = self.major,
-                            minor = self.minor,
-                            abiflags = self.abiflags,
-                            platform = platform
-                        )
-                    } else {
-                        // On windows the abiflags are missing, but this seems to work
-                        format!(
-                            "cp{major}{minor}-none-{platform}",
-                            major = self.major,
-                            minor = self.minor,
-                            platform = platform
-                        )
-                    }
+                    format!(
+                        "cp{major}{minor}-cp{major}{minor}{abiflags}-{platform}",
+                        major = self.major,
+                        minor = self.minor,
+                        abiflags = self.abiflags,
+                        platform = platform
+                    )
                 }
                 InterpreterKind::PyPy => {
                     // pypy uses its version as part of the ABI, e.g.
@@ -573,6 +580,7 @@ impl PythonInterpreter {
 
     /// Checks whether the given command is a python interpreter and returns a
     /// [PythonInterpreter] if that is the case
+    #[instrument(skip_all, fields(executable = %executable.as_ref().display()))]
     pub fn check_executable(
         executable: impl AsRef<Path>,
         target: &Target,
@@ -694,6 +702,7 @@ impl PythonInterpreter {
                     .ext_suffix
                     .context("syconfig didn't define an `EXT_SUFFIX` ಠ_ಠ")?,
                 pointer_width: None,
+                gil_disabled: message.gil_disabled,
             },
             executable,
             platform,
@@ -988,11 +997,11 @@ mod tests {
         let target =
             Target::from_target_triple(Some("x86_64-unknown-linux-gnu".to_string())).unwrap();
         let pythons = PythonInterpreter::find_by_target(&target, None);
-        assert_eq!(pythons.len(), 10);
+        assert_eq!(pythons.len(), 12);
 
         let pythons = PythonInterpreter::find_by_target(
             &target,
-            Some(&VersionSpecifiers::from_str(">=3.7").unwrap()),
+            Some(&VersionSpecifiers::from_str(">=3.8").unwrap()),
         );
         assert_eq!(pythons.len(), 10);
 
@@ -1000,7 +1009,7 @@ mod tests {
             &target,
             Some(&VersionSpecifiers::from_str(">=3.10").unwrap()),
         );
-        assert_eq!(pythons.len(), 4);
+        assert_eq!(pythons.len(), 6);
     }
 
     #[test]
@@ -1009,6 +1018,7 @@ mod tests {
             (".cpython-37m-x86_64-linux-gnu.so", Some("cp37m")),
             (".cpython-310-x86_64-linux-gnu.so", Some("cp310")),
             (".cpython-310-darwin.so", Some("cp310")),
+            (".cpython-313t-darwin.so", Some("cp313t")),
             (".cp310-win_amd64.pyd", Some("cp310")),
             (".cp39-mingw_x86_64.pyd", Some("cp39")),
             (".cpython-312-wasm32-wasi.so", Some("cp312")),
